//Initialize function
var init = function () {
	// TODO:: Do your initialization job
	console.log("init() called");

	$("#exitfooter .ui-btn-back").bind("vclick", function() {
		tizen.application.exit();
		return false;
	});
	
	onPageLoad();
};


$(document).ready(init);

var canvas = null;
var ctx = null;
var item_width;
var prev_x = -1;
var prev_y = -1;
var header_height = 60;
var current_color = "#F00";
var brush_size = 3;
var top_item_count = 5;
var selbrush = 0;
var selcolor = 2;

var color_array = [
"RED","BLACK"
];

//Check if touch is within the panel
function isWithinPanelBound(y) {
	return y < (header_height + item_width + brush_size);
}


//Line from the last position to current position
function drawLine(x, y) {
	ctx.lineWidth = brush_size;
	ctx.strokeStyle = current_color;
	ctx.beginPath();
	ctx.moveTo(prev_x, prev_y);
	ctx.lineTo(x, y);
	ctx.stroke();
}

//Check if touch is valid for drawing line and draw the line
function drawOnTouchMove(x, y) 
{
	if (isWithinPanelBound(y)) 
	{	
		prev_x = -1;
		prev_y = -1;
		return;
	}
	if (x || y) 
	{
		if ((prev_x === -1) || prev_y === -1) 
		{
			prev_x = x;
			prev_y = y;
		}
		drawLine(x, y);
		prev_x = x;
		prev_y = y;
	}
}

//Process the touch events
function processEvent(x, y) 
{
	if (!isWithinPanelBound(y))
		return;

	var eventIndex = parseInt(x / item_width, 10);

	switch(eventIndex)
	{
	case 0:
		brush_size = 3;
		selbrush = 0;
		break;
	case 1:
		brush_size = 8;
		selbrush = 1;
		break;
	case 2: //Intentional avoid of break
	case 3:
		current_color = color_array[eventIndex-2];
		selcolor = eventIndex;
		break;
	case 4:
		ctx.clearRect(0, header_height + item_width, canvas.width, canvas.height - header_height);
		break;
	default:
		break;
	}
	if((eventIndex >= 0) && (eventIndex <=3))
	{
		ctx.clearRect(0, 0, canvas.width, header_height + item_width);
		drawTopItems();
	}

}

//When canvas is touched, save the coordinates into prev_x and prev_y variables
function onTouchStart(event)
{
	event.preventDefault();

	var touchEvent, x, y;

	touchEvent = event.changedTouches[0];
	x = touchEvent.pageX;
	y = touchEvent.pageY;

	if (x || y) 
	{
		if (!isWithinPanelBound(y)) 
		{
			prev_x = touchEvent.pageX;
			prev_y = touchEvent.pageY;
		}
	}
}

//Draw a line segment when touch move event occurs
function onTouchMove(event)
{
	event.preventDefault();

	var touchEvent, x, y;

	touchEvent = event.changedTouches[0];
	x = touchEvent.pageX;
	y = touchEvent.pageY;

	drawOnTouchMove(x, y);
}


//Capture the touch end event
function onTouchEnd(event)
{
	event.preventDefault();

	var touchEvent;
	touchEvent = event.changedTouches[0];

	if (isWithinPanelBound(touchEvent.pageY)) 
	{
		processEvent(touchEvent.pageX, touchEvent.pageY);
	} 
}

//touch cancelled
function onTouchCancel(event)
{
	event.preventDefault();
}

//Draw the color and brush size items on top of page
function drawTopItems() 
{
	var i;

//	Item for small brush
	ctx.fillStyle = "GREY";
	ctx.strokeStyle = "GREY";
	ctx.beginPath();
	ctx.arc(item_width/2, header_height + item_width/2 - 4, item_width/9, 0, 2*Math.PI, true);
	ctx.closePath();
	ctx.fill();

//	Item for wider brush
	ctx.beginPath();
	ctx.arc(item_width*3/2, header_height + item_width/2 - 4, item_width/4, 0, 2*Math.PI, true);
	ctx.closePath();
	ctx.fill();

//	Item for red and black color
	for (i=0; i<color_array.length; i = i + 1) {
		ctx.fillStyle = color_array[i];
		ctx.fillRect((i+2)*item_width + 3, header_height, item_width - 6, item_width - 6);
	}

//	clear Item
	ctx.font="20px Arial";
	ctx.fillText("Clear",item_width*(top_item_count - 1) + 10, header_height + item_width/2);

//	draw an outer border
	for (i=0; i<top_item_count; i = i + 1) 
	{
		if((selbrush === i) || (selcolor === i))
		{
			ctx.lineWidth = 5;
		}
		else
		{
			ctx.lineWidth = 2;
		}
		ctx.strokeRect(i*item_width + 3, header_height, item_width - 6, item_width - 6);
	}
}

//Page is loaded
function onPageLoad()
{
	document.addEventListener("touchstart", onTouchStart, false);
	document.addEventListener("touchmove", onTouchMove, false);
	document.addEventListener("touchend", onTouchEnd, false);
	document.addEventListener("touchcancel", onTouchCancel, false);

//	Create a canvas that covers the entire screen
	canvas = document.createElement('canvas');
	canvas.height = screen.availHeight;
	canvas.width = screen.availWidth;
	document.getElementById('canvas').appendChild(canvas);
	ctx = canvas.getContext("2d");

	item_width = canvas.width/top_item_count;
	drawTopItems();
}
